#
# spec file for package liburiparser1
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           liburiparser1
Url:            http://uriparser.sourceforge.net/
%define pkg_name uriparser
Version:        0.8.1
Release:        6.4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        A strictly RFC 3986 compliant URI parsing library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Source:         http://sourceforge.net/projects/uriparser/files/Sources/%{version}/%{pkg_name}-%{version}.tar.bz2
Source1:        baselibs.conf
Patch0:         uriparser-doxygen.patch
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libxdot)

%description
uriparser is a strictly RFC 3986 compliant URI parsing library. It is
cross-platform, fast, and supports Unicode.

%package -n uriparse
Summary:        A strictly RFC 3986 compliant URI parsing command line tool
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

%description -n uriparse
uriparser is a strictly RFC 3986 compliant URI parsing library. It is
cross-platform, fast, and supports Unicode.

uriparse is a command line tool which allows to parse URI's and show how
the liburiparser splits it into components.

%package -n liburiparser-devel
Summary:        A strictly RFC 3986 compliant URI parsing library
License:        BSD-3-Clause and LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel

%description -n liburiparser-devel
uriparser is a strictly RFC 3986 compliant URI parsing library. It is
cross-platform, fast, and supports Unicode.

%prep
%setup -q -n %{pkg_name}-%{version}
%patch0 -p 1
#file is dated in the future..
#find . -type f -exec touch {} +
# This is ridiculous but the patch doesn't apply at all for no reasons
sed -i "s|# .qhp output|HTML_TIMESTAMP=NO|g" doc/Doxyfile.in

%build
%configure --disable-static --with-pic --disable-test --docdir=%{_docdir}/%{pkg_name}
make %{?_smp_mflags}

%install
%{__make} install DESTDIR=%{buildroot}
%{__rm} -f %{buildroot}%{_libdir}/*.la

%check
export MALLOC_CHECK_=2 MALLOC_PERTURB_=$((${RANDOM:-256} % 256))
%{__make} check
unset MALLOC_CHECK_ MALLOC_PERTURB_

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/liburiparser.so.1*

%files -n uriparse
%defattr(-,root,root)
%{_bindir}/uriparse

%files -n liburiparser-devel
%defattr(-,root,root)
%dir %{_includedir}/%{pkg_name}
%{_includedir}/%{pkg_name}/*.h
%{_libdir}/liburiparser.so
%{_libdir}/pkgconfig/liburiparser.pc
%{_docdir}/%{pkg_name}/html/*
%dir %{_docdir}/%{pkg_name}
%dir %{_docdir}/%{pkg_name}/html

%changelog
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.8.1
  * Fixed: Sync URI_VER_* preprocessor defines (were at 0.7.6, bug #23)
  * Fixed: Bug in internal function that may flip uriEqualsUri results around
  * Added: Function uriAddBaseUriEx allowing to resolve URIs with
    a scheme identical to that of the base URI to resolve against
    as if the URI to resolve had no scheme specified, when flag
    URI_RESOLVE_IDENTICAL_SCHEME_COMPAT is specified (feature request #4)
  * Soname: 1:17:0
- Update uriparser-0.7.5-doxygen.patch
  > uriparser-doxygen.patch
- Add pkgconfig(libxdot) require; new upstream dependency
- Update download source Url to current sourceforge location
- Split out uriparse binary into his own package
* Tue May 27 2014 crrodriguez@opensuse.org
- Extend uriparser-0.7.5-doxygen.patch so doxygen does not
  generate timestamped files.
* Sun Feb  3 2013 coolo@suse.com
- update license to new format
* Mon Jan 30 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
* Mon Sep  6 2010 coolo@novell.com
- fix compile, newer doxygen does not use .gif anymore
* Fri Apr  9 2010 davejplater@gmail.com
- Update to version 0.7.5 fixed doxygen build with uriparser-0.7.5-doxygen.patch
- Upstream changes :-
  * Added: pkg-config file
  * Fixed: File Doxyfile.in was missing from release archives
    Thanks to Rakesh Pandit for reporting!
  * Fixed: Doc generation troubles
  * Changed: No longer shipping bundled libcpptest
  * Changed: New dependencies:
  - libcpptest 1.1.0 or later
  - pkg-config (for libcpptest detection)
    Both dependencies can be disable through configuring
    with --disable-test, which excludes the test suite
    from compilation.
  * Soname: 1:10:0
* Sun Sep  6 2009 meissner@suse.de
- use correct version in .spec file, removed unnecessary CFLAGS/CXXFLAGS
  stuff now default.
* Tue Dec 23 2008 pascal.bleser@opensuse.org
- update to version 0.7.4:
  * fixes null pointer de-referencing and memory leaks in two places
- changes from 0.7.3:
  * fixes a small bug with parsing
* Sun Sep  7 2008 schwab@suse.de
- Remove conflicting libtool macros.
* Tue Sep  2 2008 crrodriguez@suse.de
- update to version 0.7.2
  Fixed: Bad cleanup logic in functions
  uriAddBaseUri(..)
    uriRemoveBaseUri(..)
    Previously you needed to call uriFreeUriMembers on return code
    URI_ERROR_MALLOC and only then. So that's why these functions now
    take cleanup off your shoulders. An extra call to uriFreeUriMembers
    from your side is still needed in case of success.
  * Soname: 1:7:0
* Mon Apr 28 2008 crrodriguez@suse.de
- update to version 0.7.1
  * Fixed: Bogus syntax error when parsing URIs with port-like
    passwords, e.g. "http://user:21@host/" (#1948038)
    Thanks to Friedrich Delgado Friedrichs for reporting!
  * Fixed: Parser did not handle trailing slashes correctly in some cases,
    which also made the structures produced from parsing "http://e.com/"
    and "http://e.com" indistinguishable. (#1950126)
    Thanks to Edward Z. Yang for reporting!
* Fri Apr  4 2008 crrodriguez@suse.de
- update to version 0.7.0
  * Added: Dissection and composition of query strings
  * Added: Documentation improvements
    (in|out|inout indicators, addition of \since and \see)
  * Changed: Code::Blocks project files updated from file format
    version 1.4 to 1.6, which is produced by Code::Blocks 8.02
  * Added: Code::Blocks workspace file
  * Changed: Soname set to 1:5:0
* Tue Mar 11 2008 crrodriguez@suse.de
- fix buildRequires
* Mon Feb 25 2008 crrodriguez@suse.de
- version 0.6.4
  * Added: Syntax-based normalization can now handle relative URIs,
    e.g. "../../a/b/.././c" is normalized to "../../a/c"
  * Fixed: Normalization code could free foreign memory
  * Fixed: Normalization processed the path segment even when asked not to
  * Fixed: Documentation bug not requiring enough memory for the output
    buffer when converting a relative file URI back to a filename
  * Changed: Soname set to 1:4:0
* Mon Feb 11 2008 crrodriguez@suse.de
- version 0.6.3
- Fixed: Two major crash bugs in normalization code
- Added: Brief usage tutorial
- Changed: Soname set to 1:3:0
* Mon Feb  4 2008 crrodriguez@suse.de
- version 0.6.1
* Thu Oct 18 2007 crrodriguez@suse.de
- update to version 0.6.0 , liburiparse1
* Wed Aug 15 2007 crrodriguez@suse.de
- first package for the OBS
